@@ -8,7 +8,9 @@ use super::*;
 pub(crate) enum Attribute {
   Linux,
   Macos,
+  NoCd,
   NoExitMessage,
+  Private,
   Unix,
   Windows,
 }
