@@ -143,6 +143,7 @@ impl Config {
       )
       .arg(
         Arg::with_name(arg::DRY_RUN)
+          .short("n")
           .long("dry-run")
           .help("Print what just would do without doing it")
           .conflicts_with(arg::QUIET),
@@ -433,7 +434,7 @@ impl Config {
       }
     }
 
-    let positional = Positional::from_values(matches.values_of(arg::ARGUMENTS))?;
+    let positional = Positional::from_values(matches.values_of(arg::ARGUMENTS));
 
     for (name, value) in positional.overrides {
       overrides.insert(name.clone(), value.clone());
@@ -771,11 +772,17 @@ mod tests {
   }
 
   test! {
-    name: dry_run_true,
+    name: dry_run_long,
     args: ["--dry-run"],
     dry_run: true,
   }
 
+  test! {
+    name: dry_run_short,
+    args: ["-n"],
+    dry_run: true,
+  }
+
   error! {
     name: dry_run_quiet,
     args: ["--dry-run", "--quiet"],
