@@ -1,7 +1,4 @@
-use super::*;
-
-use CompileErrorKind::*;
-use TokenKind::*;
+use {super::*, CompileErrorKind::*, TokenKind::*};
 
 /// Just language lexer
 ///
@@ -121,7 +118,7 @@ impl<'src> Lexer<'src> {
 
   fn presume(&mut self, c: char) -> CompileResult<'src, ()> {
     if !self.next_is(c) {
-      return Err(self.internal_error(format!("Lexer presumed character `{}`", c)));
+      return Err(self.internal_error(format!("Lexer presumed character `{c}`")));
     }
 
     self.advance()?;
@@ -272,7 +269,7 @@ impl<'src> Lexer<'src> {
     matches!(c, 'a'..='z' | 'A'..='Z' | '_')
   }
 
-  /// True if `c` can be a continuation character of an idenitifier
+  /// True if `c` can be a continuation character of an identifier
   fn is_identifier_continue(c: char) -> bool {
     if Self::is_identifier_start(c) {
       return true;
@@ -948,7 +945,7 @@ mod tests {
 
       // Variable lexemes
       Text | StringToken | Backtick | Identifier | Comment | Unspecified => {
-        panic!("Token {:?} has no default lexeme", kind)
+        panic!("Token {kind:?} has no default lexeme")
       }
     }
   }
