@@ -116,7 +116,7 @@ impl Subcommand {
           },
           Err(err) => return Err(err.into()),
           Ok(search) => {
-            if config.verbosity.loud() && path != starting_path {
+            if config.verbosity.loquacious() && path != starting_path {
               eprintln!(
                 "Trying {}",
                 starting_path
@@ -181,7 +181,7 @@ impl Subcommand {
 
     let tokens = Lexer::lex(src)?;
     let ast = Parser::parse(&tokens)?;
-    let justfile = Analyzer::analyze(ast.clone())?;
+    let justfile = Analyzer::analyze(&ast)?;
 
     if config.verbosity.loud() {
       for warning in &justfile.warnings {
@@ -383,12 +383,12 @@ impl Subcommand {
           for op in diff.ops() {
             for change in diff.iter_changes(op) {
               let (symbol, color) = match change.tag() {
-                ChangeTag::Delete => ("-", config.color.stderr().diff_deleted()),
-                ChangeTag::Equal => (" ", config.color.stderr()),
-                ChangeTag::Insert => ("+", config.color.stderr().diff_added()),
+                ChangeTag::Delete => ("-", config.color.stdout().diff_deleted()),
+                ChangeTag::Equal => (" ", config.color.stdout()),
+                ChangeTag::Insert => ("+", config.color.stdout().diff_added()),
               };
 
-              eprint!("{}{symbol}{change}{}", color.prefix(), color.suffix());
+              print!("{}{symbol}{change}{}", color.prefix(), color.suffix());
             }
           }
         }
