@@ -18,7 +18,7 @@ fn interrupt_test(arguments: &[&str], justfile: &str) {
   let start = Instant::now();
 
   let mut child = Command::new(executable_path("just"))
-    .current_dir(tmp)
+    .current_dir(&tmp)
     .args(arguments)
     .spawn()
     .expect("just invocation failed");
