@@ -1,6 +1,9 @@
 pub(crate) use {
   crate::{
-    assert_stdout::assert_stdout, assert_success::assert_success, tempdir::tempdir, test::Test,
+    assert_stdout::assert_stdout,
+    assert_success::assert_success,
+    tempdir::tempdir,
+    test::{Output, Test},
   },
   cradle::input::Input,
   executable_path::executable_path,
@@ -17,8 +20,8 @@ pub(crate) use {
     fs,
     io::Write,
     iter,
-    path::{Path, PathBuf, MAIN_SEPARATOR},
-    process::{Command, Output, Stdio},
+    path::{Path, PathBuf},
+    process::{Command, Stdio},
     str,
   },
   tempfile::TempDir,
