@@ -19,7 +19,7 @@ FLAGS:
 
 OPTIONS:
     --tag TAG       Tag (version) of the crate to install, defaults to latest release
-    --to LOCATION   Where to install the binary [default: ~/.cargo/bin]
+    --to LOCATION   Where to install the binary [default: ~/bin]
     --target TARGET
 EOF
 }
@@ -98,7 +98,7 @@ if [ -z ${target-} ]; then
 fi
 
 if [ -z ${dest-} ]; then
-  dest="$HOME/.cargo/bin"
+  dest="$HOME/bin"
 fi
 
 if [ -z ${tag-} ]; then
